@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -524,22 +524,6 @@ bool admin_gnu::parse(ST::string & in)
             }
 		  else
             {
-
-#if defined(BORLAND_OUTPUT_WINDOW)
-            if (type.getvalue() == "rtf")
-              Results->ResultsRichEdit->PlainText = false;
-            else
-              Results->ResultsRichEdit->PlainText = true;
-
-            Results->ResultsRichEdit->Lines->SaveToFile(uw.getPath().strtochar());
-            Results->ResultsRichEdit->Modified = false;
-            Results->ResultsRichEdit->Tag = true;
-            Results->Caption = uw.getPath().strtochar();
-#elif defined (JAVA_OUTPUT_WINDOW)
-            jmethodID javasaveoutput = adminb.Java->GetMethodID(adminb.BayesX_cls, "JavaSaveOutput", "()V");
-            adminb.Java->CallVoidMethod(adminb.BayesX_obj, javasaveoutput);
-#endif
-
             }
           }
         else
@@ -551,12 +535,6 @@ bool admin_gnu::parse(ST::string & in)
         }*/
 /*     else if (firsttoken == "clearoutput")
        {
-#if defined(BORLAND_OUTPUT_WINDOW)
-       Results->ResultsRichEdit->Clear();
-#elif defined (JAVA_OUTPUT_WINDOW)
-       jmethodID clearoutput = adminb.Java->GetMethodID(adminb.BayesX_cls, "ClearOutput", "()V");
-       adminb.Java->CallVoidMethod(adminb.BayesX_obj, clearoutput);
-#endif
        }*/
 	 else if (firsttoken == "logopen")
 		{
