@@ -643,14 +643,14 @@ void FULLCOND_kriging2::compute_knots(const vector<double> & xvals,
                             // zum Kandidaten wird (ohne Beitrag des neuen Knotens)
 
     int swapindex;                        // Index des zu tauschenden Kandidaten
-                                          // (Kandidat mit dem minimalen Kriterium beim Loop ber den aktuellen Knoten)
+                                          // (Kandidat mit dem minimalen Kriterium beim Loop ueber den aktuellen Knoten)
 
-    double covcritold=0; // Coverage-Kriterium (ndert sich nur nach Durchlauf ber Knoten)
-    double covcritnew=-1;   // Neues Coverage-Kriterium (ndert sich nur nach Durchlauf ber Knoten)
-    double covcritoldi;  // Coverage-Kriterium vorm Swappen von Knoten i (ndert sich nach jedem Swap)
-    double covcritnewi;  // Neues Coverage-Kriterium beim Swappen von Knoten i (ndert sich nach jedem Swap)
+    double covcritold=0; // Coverage-Kriterium (aendert sich nur nach Durchlauf ueber Knoten)
+    double covcritnew=-1;   // Neues Coverage-Kriterium (aendert sich nur nach Durchlauf ueber Knoten)
+    double covcritoldi;  // Coverage-Kriterium vorm Swappen von Knoten i (aendert sich nach jedem Swap)
+    double covcritnewi;  // Neues Coverage-Kriterium beim Swappen von Knoten i (aendert sich nach jedem Swap)
 
-    // Startdesign und Kandidaten zufllig bestimmen
+    // Startdesign und Kandidaten zufaellig bestimmen
 
     datamatrix u(nrdiffobs,1,0);
     statmatrix<int> ind(nrdiffobs,1,0);
@@ -735,10 +735,10 @@ void FULLCOND_kriging2::compute_knots(const vector<double> & xvals,
 
         for(j=0; j<nrcand; j++)
           {
-          // Loop ber die Kandidaten. Jeweil das Coverage-Kriterium bei Swap i vs. j ausrechnen
+          // Loop ueber die Kandidaten. Jeweil das Coverage-Kriterium bei Swap i vs. j ausrechnen
           // und gegebenenfalls swapindex umsetzen.
           covcritnewi = 0;
-          // Loopen ber Zeilensummen ohne j
+          // Loopen ueber Zeilensummen ohne j
           for(k=0; k<j; k++)
             {
             covcritnewi += pow(rowsumswithouti(k,0) +
@@ -819,7 +819,7 @@ void FULLCOND_kriging2::update()
   if(lambdaconst == true)
     sigma2 = likep->get_scale(column)/lambda;
 
-  if(optionsp->get_nriter()==1)       // posterior mode Schtzung bernehmen
+  if(optionsp->get_nriter()==1)       // posterior mode Schaetzung uebernehmen
     betaold.assign(beta);
 
   if(utype == gaussian)
@@ -869,7 +869,7 @@ void FULLCOND_kriging2::update_gaussian()
 
   likep->substr_linearpred(spline);
 
-  if(changingweight)  // fr t-link
+  if(changingweight)  // fuer t-link
     {
     datamatrix help = X.transposed();
     help.multdiagback(likep->get_weight());
@@ -885,7 +885,7 @@ void FULLCOND_kriging2::update_gaussian()
   for(i=0;i<nrpar;i++,work++)
     *work = rand_normal();
 
-  likep->compute_respminuslinpred(mu,column);   // nicht ndern wegen multgaussian
+  likep->compute_respminuslinpred(mu,column);   // nicht aendern wegen multgaussian
 
 //  compute_XWtildey(likep->get_weight(),scaleinv);
   double * weightp = likep->get_weightp();
